@@ -9,7 +9,6 @@ from derrick.core.detector_report import DetectorReport
 from derrick.core.rigging import Rigging
 from derrick.detectors.general.image_repo import ImageRepoDetector
 from derrick.detectors.image.java import JavaVersionDetector
-from derrick.core.common import *
 
 RUNTIME = "Maven"
 
@@ -30,11 +29,11 @@ class MavenRigging(Rigging):
         dr = DetectorReport()
         docker_node = dr.create_node("Dockerfile.j2")
         docker_node.register_detector(JavaVersionDetector())
-        if is_windows() is not True:
-            docker_compose_node = dr.create_node("docker-compose.yml.j2")
-            docker_compose_node.register_detector(ImageRepoDetector())
 
-            jenkins_file_node = dr.create_node("Jenkinsfile.j2")
-            jenkins_file_node.register_detector(ImageRepoDetector())
+        docker_compose_node = dr.create_node("docker-compose.yml.j2")
+        docker_compose_node.register_detector(ImageRepoDetector())
+
+        jenkins_file_node = dr.create_node("Jenkinsfile.j2")
+        jenkins_file_node.register_detector(ImageRepoDetector())
 
         return dr.generate_report()
